@@ -8,11 +8,11 @@ use 5.010;
 
 use base 'Exporter';
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.058'; # VERSION
+our $VERSION = '0.059'; # VERSION
 
 @EXPORT      = qw();
 %EXPORT_TAGS = ();
-@EXPORT_OK   = qw(uniq_rows uniq_rows_secure as_matrix preview);
+@EXPORT_OK   = qw(uniq_rows uniq_rows_secure as_matrix preview combine_to_matrix xls_idx0_to_a1 xls_range0_to_a1);
 
 sub uniq_rows {
   my $matrix = shift;
@@ -48,15 +48,31 @@ sub as_matrix {
   return \@m;
 }
 
+sub combine_to_matrix {
+  my ( $data, $keys ) = @_;
+
+  if ( !( $keys && @$keys ) && @$data ) {
+    $keys = [ sort keys %{ $data->[0] } ];
+  }
+
+  return unless ( $data && @$data );
+
+  my @res;
+  for my $d (@$data) {
+    push @res, [ map { $d->{$_} } @$keys ];
+  }
+  return \@res;
+}
+
 sub preview {
-  my ($m, $c) = @_;
+  my ( $m, $c ) = @_;
 
   return unless ( $m && @$m > 0 );
   my @preview;
   if ( ref $m->[0] ) {
     if ( @$m >= 6 ) {
       push @preview, @{$m}[ 0 .. 2 ];
-      push @preview, [("...") x scalar @{ $m->[0] }] if(($c->{dots} && @$m > 6) || $c->{force_dots});
+      push @preview, [ ("...") x scalar @{ $m->[0] } ] if ( ( $c->{dots} && @$m > 6 ) || $c->{force_dots} );
       push @preview, @{$m}[ -3, -2, -1 ];
     } else {
       @preview = @$m;
@@ -64,9 +80,9 @@ sub preview {
   } else {
     if ( @$m >= 6 ) {
       push @preview, @{$m}[ 0 .. 2 ];
-      
-      push @preview, '...' if(($c->{dots} && @$m > 6) || $c->{force_dots});
-      
+
+      push @preview, '...' if ( ( $c->{dots} && @$m > 6 ) || $c->{force_dots} );
+
       push @preview, @{$m}[ -3, -2, -1 ];
     } else {
       @preview = @$m;
@@ -76,4 +92,30 @@ sub preview {
 
 }
 
+sub xls_idx0_to_a1 {
+  my $idx = shift;
+
+  my @letters = 'A' .. 'Z';
+
+  my $string_idx = '';
+
+  do {
+    $idx-- if ($string_idx);
+    $string_idx .= $letters[ ( $idx % 26 ) ];
+    $idx = int( $idx / 26 );
+  } while ( $idx > 0 );
+
+  return reverse $string_idx;
+}
+
+sub xls_range0_to_a1 {
+  my $from = shift;
+  my $to   = shift;
+  if ( !defined($to) ) {
+    return idx0_to_a1($from) . ":" . idx0_to_a1($from);
+  }
+
+  return idx0_to_a1($from) . ":" . idx0_to_a1($to);
+}
+
 1;
