@@ -6,13 +6,15 @@ use warnings;
 use strict;
 use Carp;
 
+use String::ShellQuote;
+
 use base 'Exporter';
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.058'; # VERSION
+our $VERSION = '0.059'; # VERSION
 
 @EXPORT      = qw();
 %EXPORT_TAGS = ();
-@EXPORT_OK   = qw(undef_slice slice invslice flatten hash_merge as_arrayref);
+@EXPORT_OK   = qw(undef_slice slice invslice flatten hash_merge as_arrayref sys_pipe);
 
 sub slice {
   my ( $hr, @k ) = @_;
@@ -98,6 +100,22 @@ sub as_arrayref {
   }
 }
 
+sub sys_pipe {
+  my $cmd;
+
+  for my $e (@_) {
+    if ( ref $e eq 'ARRAY' ) {
+      $cmd .= shell_quote(@$e) . " ";
+    } elsif ( $e =~ /^>>|\d?>|<|<<|\||\d?>\&\d$/ ) {
+      $cmd .= $e . " ";
+    } else {
+      $cmd .= shell_quote($e) . " ";
+    }
+  }
+  chomp $cmd;
+  system($cmd) == 0 or confess "system failed: $?\n$cmd";
+}
+
 1;
 
 __END__
